Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(497)

Unified Diff: content/browser/memory/memory_message_filter.h

Issue 1641813002: Provide renderers with memory pressure signals. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@contentapi
Patch Set: Addressed creis' comments. Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/memory/memory_message_filter.h
diff --git a/content/browser/memory/memory_message_filter.h b/content/browser/memory/memory_message_filter.h
index ad13662477e7b64483c760dab093e71e50995982..5241b9cc55624deff047aadfca75bb60d4a05d96 100644
--- a/content/browser/memory/memory_message_filter.h
+++ b/content/browser/memory/memory_message_filter.h
@@ -36,7 +36,7 @@ class CONTENT_EXPORT MemoryMessageFilter : public BrowserMessageFilter {
base::MemoryPressureListener::MemoryPressureLevel level);
protected:
- friend class MemoryPressureController;
+ friend class MemoryPressureControllerImpl;
~MemoryMessageFilter() override;
@@ -46,7 +46,7 @@ class CONTENT_EXPORT MemoryMessageFilter : public BrowserMessageFilter {
private:
// The untyped process host and ProcessType associated with this filter
// instance. The process host is stored as untyped because it is only used as
// a key in MemoryPressureController; at no point is it ever deferenced to
// invoke any members on a process host.
const void* process_host_;
ProcessType process_type_;
@@ -46,7 +46,7 @@ class CONTENT_EXPORT MemoryMessageFilter : public BrowserMessageFilter {
// The untyped process host and ProcessType associated with this filter
// instance. The process host is stored as untyped because it is only used as
- // a key in MemoryPressureController; at no point is it ever deferenced to
+ // a key in MemoryPressureControllerImpl; at no point is it ever deferenced to
// invoke any members on a process host.
const void* process_host_;
« no previous file with comments | « content/browser/devtools/protocol/memory_handler.cc ('k') | content/browser/memory/memory_message_filter.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698